#!/bin/bash

function usage() {
	echo "Usage: $0 [-d db name] [-i db instance]"
}

FLAG_OW=N
DB_NAME=IFEDB
DB_INST=ol_informix1210
while getopts 'd:i:' OPTION
do
  case $OPTION in
  d)	DB_NAME="$OPTARG";;
  i)	DB_INST="$OPTARG";;
  ?)	usage
  		exit 1;;
  esac
done
shift $(($OPTIND - 1))

if [ $# -gt 0 ]; then
	echo "Invalid arguments"
	usage
	exit 1
fi

# initialize informix environment variables
export INFORMIXDIR=/opt/IBM/informix
export INFORMIXSERVER=$DB_INST
export ONCONFIG=onconfig.$INFORMIXSERVER
export PATH=$INFORMIXDIR/bin:$PATH
export INFORMIXSQLHOSTS=$INFORMIXDIR/etc/sqlhosts.$INFORMIXSERVER
export DBTEMP=$INFORMIXDIR/infxtmp
export CLIENT_LOCALE=EN_US.CP1252
export DB_LOCALE=EN_US.8859-1

# send to standard output
DBACCESS="$INFORMIXDIR/bin/dbaccess -e"
DBCOMMAND="$DBACCESS $DB_NAME"

$DBCOMMAND << EOSQL
  	truncate table AHA.PACKAGE_DEGRADATION;
  	truncate table AHA.PACKAGE_TREATMENT_EXCLUDE;
  	truncate table AHA.PACKAGE_TREATMENT_INCLUDE;	
  	truncate table AHA.PACKAGE_TREATMENT;
  	truncate table AHA.PACKAGE_INDEX;	
  	truncate table AHA.PACKAGE_FACTOR;
  	truncate table AHA.PACKAGE_DRIVER;	
  	truncate table AHA.PACKAGE_DRIVER;
  	truncate table AHA.ANALYSIS;
  	truncate table AHA.PACKAGE;
  	truncate table AHA.ANALYSIS_YEAR;
  	truncate table AHA.TREATMENT;
  	truncate table AHA.FACTOR;
  	truncate table AHA.DRIVER;
									
  	load from AHA.DRIVER.csv DELIMITER ',' INSERT INTO AHA.DRIVER;
  	load from AHA.FACTOR.csv DELIMITER ',' INSERT INTO AHA.FACTOR;
  	load from AHA.TREATMENT.csv DELIMITER ',' INSERT INTO AHA.TREATMENT;
  	load from AHA.ANALYSIS_YEAR.csv DELIMITER ',' INSERT INTO AHA.ANALYSIS_YEAR;
  	load from AHA.PACKAGE.csv DELIMITER ',' INSERT INTO AHA.PACKAGE;
  	load from AHA.ANALYSIS.csv DELIMITER ',' INSERT INTO AHA.ANALYSIS;
  	load from AHA.PACKAGE_DRIVER.csv DELIMITER ',' INSERT INTO AHA.PACKAGE_DRIVER(PACKAGE_ID, DRIVER_ID, DRIVER_WEIGHT);
  	load from AHA.PACKAGE_FACTOR.csv DELIMITER ',' INSERT INTO AHA.PACKAGE_FACTOR(PACKAGE_ID, DRIVER_ID, FACTOR_ID, FACTOR_WEIGHT, DEFAULT_VALUE);
  	load from AHA.PACKAGE_INDEX.csv DELIMITER ',' INSERT INTO AHA.PACKAGE_INDEX(PACKAGE_ID, DRIVER_ID, FACTOR_ID, INDEX_SEQUENCE_ID, INDEX_TYPE, FROM_RANGE, TO_RANGE, STRING_VALUE, INT_VALUE, INDEX_VALUE);
  	load from AHA.PACKAGE_TREATMENT.csv DELIMITER ',' INSERT INTO AHA.PACKAGE_TREATMENT(PACKAGE_ID, TREATMENT_ID, UNIT, UNIT_COST, SERVICE_LIFE_EXTENSION, SERVICE_LIFE_IMPROVEMENT, DESCRIPTION);
  	load from AHA.PACKAGE_TREATMENT_INCLUDE.csv DELIMITER ',' INSERT INTO AHA.PACKAGE_TREATMENT_INCLUDE(PACKAGE_ID, TREATMENT_ID, DRIVER_ID, FROM_RANGE, TO_RANGE);
  	load from AHA.PACKAGE_TREATMENT_EXCLUDE.csv DELIMITER ',' INSERT INTO AHA.PACKAGE_TREATMENT_EXCLUDE(PACKAGE_ID, TREATMENT_ID, DRIVER_ID, FACTOR_ID, SEQUENCE_ID, INDEX_TYPE, FROM_RANGE, TO_RANGE, STRING_VALUE, INT_VALUE, FILTER_NAME, FILTER_DESCRIPTION);
  	load from AHA.PACKAGE_DEGRADATION.csv DELIMITER ',' INSERT INTO AHA.PACKAGE_DEGRADATION(PACKAGE_ID, FACTOR_ID, AGE, DESCRIPTION, CUMULATIVE_DEGRADATION);
EOSQL

